import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'deployPlatform.m.dart';


class DeployPlatformService extends JsonRpcClientBase {
	DeployPlatformService(
		String host, {
		String serviceName = "IDeployPlatformService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => DeployPlatServerInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => DeployPlatOperatorDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => DeployRecordInfoDTO.fromJson(map));
	}

	Future<List<DeployPlatServerInfoDTO>> getServerListAsync() async {
		var rpcRst = await call("GetServerListAsync", );
		var result = (rpcRst as List).map((e)=>DeployPlatServerInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<DeployPlatOperatorDTO>> getOperatorListAsync() async {
		var rpcRst = await call("GetOperatorListAsync", );
		var result = (rpcRst as List).map((e)=>DeployPlatOperatorDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<DeployRecordInfoDTO>> getRecordListAsync(GetDeployRecordRequest request) async {
		var rpcRst = await call("GetRecordListAsync", request);
		var result = (rpcRst as List).map((e)=>DeployRecordInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> saveRecordAsync(SaveDeployRecordRequest request) async {
		var rpcRst = await call("SaveRecordAsync", request);
		return rpcRst;
	}

	Future<bool> removeRecordAsync(RemoveDeployRecordRequest request) async {
		var rpcRst = await call("RemoveRecordAsync", request);
		return rpcRst;
	}

	Future<bool> addOperatorAsync(AddDeployPlatOperatorRequest request) async {
		var rpcRst = await call("AddOperatorAsync", request);
		return rpcRst;
	}

	Future<bool> modifyperatorAsync(ModifyDeployPlatOperatorRequest request) async {
		var rpcRst = await call("ModifyperatorAsync", request);
		return rpcRst;
	}

	Future<bool> deleteOperatorAsync(DeleteDeployPlatOperatorRequest request) async {
		var rpcRst = await call("DeleteOperatorAsync", request);
		return rpcRst;
	}

	Future<List<String>> findTextWithUrlAndPrefixAsync(FindTextWithUrlAndPrefixRequest request) async {
		var rpcRst = await call("FindTextWithUrlAndPrefixAsync", request);
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<bool> generatePackageAsync(GeneratePackageRequest request) async {
		var rpcRst = await call("GeneratePackageAsync", request);
		return rpcRst;
	}

	Future<List<String>> getPackageLogsAsync() async {
		var rpcRst = await call("GetPackageLogsAsync", );
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<DeployRecordInfoDTO> getPackageAsync(GetPackageRequest request) async {
		var rpcRst = await call("GetPackageAsync", request);
		var result = DeployRecordInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> cancelPackagingAsync(CancelPackagingRequest request) async {
		var rpcRst = await call("CancelPackagingAsync", request);
		return rpcRst;
	}

}

