import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'education.m.dart';

import 'liveConsultation.m.dart';


class EducationService extends JsonRpcClientBase {
	EducationService(
		String host, {
		String serviceName = "IEducationService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => CourseLabelDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<CoursePageDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => CoursePageDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => CourseInfoDetailDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<StudentInCoursePageDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => StudentInCoursePageDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => UserGroupDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<StudentInfoDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => StudentInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<VideoInfoDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => VideoInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => BuyCourseResult.fromJson(map));
		FJsonConvert.setDecoder((map) => BaseCourseExaminationDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => CourseExaminationDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<BaseStudentExaminationDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => BaseStudentExaminationDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => StudentExaminationDetailDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => InitiateLiveCourseResult.fromJson(map));
		FJsonConvert.setDecoder((map) => JoinLiveCourseResult.fromJson(map));
		FJsonConvert.setDecoder((map) => LiveHeartRateResult.fromJson(map));
		FJsonConvert.setDecoder((map) => LiveCourseBaseResult.fromJson(map));
		FJsonConvert.setDecoder((map) => LiveCourseMember.fromJson(map));
		FJsonConvert.setDecoder((map) => RemoteExaminationPageDTO.fromJson(map));
	}

	Future<List<CourseLabelDTO>> getCourseLabelsAsync(QueryCourseLabelListRequest request) async {
		var rpcRst = await call("GetCourseLabelsAsync", request);
		var result = (rpcRst as List).map((e)=>CourseLabelDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> applyCourseAsync(ApplyCourseRequest request) async {
		var rpcRst = await call("ApplyCourseAsync", request);
		return rpcRst;
	}

	Future<PageResult<CoursePageDTO>> findCoursePagesAsync(FindCoursePagesRequest request) async {
		var rpcRst = await call("FindCoursePagesAsync", request);
		var result = PageResult<CoursePageDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> deleteCourseByCodeAsync(DeleteCourseByCodeRequest request) async {
		var rpcRst = await call("DeleteCourseByCodeAsync", request);
		return rpcRst;
	}

	Future<bool> updateCourseAsync(UpdateCourseRequest request) async {
		var rpcRst = await call("UpdateCourseAsync", request);
		return rpcRst;
	}

	Future<CourseInfoDetailDTO> findCourseByCodeAsync(FindCourseByCodeRequest request) async {
		var rpcRst = await call("FindCourseByCodeAsync", request);
		var result = CourseInfoDetailDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageResult<StudentInCoursePageDTO>> findStudentInCoursePagesAsync(FindStudentInCoursePagesRequest request) async {
		var rpcRst = await call("FindStudentInCoursePagesAsync", request);
		var result = PageResult<StudentInCoursePageDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<UserGroupDTO>> getUserGroupListsByCreatorCodeAsync(TokenRequest request) async {
		var rpcRst = await call("GetUserGroupListsByCreatorCodeAsync", request);
		var result = (rpcRst as List).map((e)=>UserGroupDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> addUserGroupAsync(UserGroupRequest request) async {
		var rpcRst = await call("AddUserGroupAsync", request);
		return rpcRst;
	}

	Future<PageResult<StudentInfoDTO>> findUserGroupStudentsPagesAsync(QueryStudentByGroupCodePageRequest request) async {
		var rpcRst = await call("FindUserGroupStudentsPagesAsync", request);
		var result = PageResult<StudentInfoDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeStudentsByGroupCodeAsync(UserGroupFilterRequest request) async {
		var rpcRst = await call("RemoveStudentsByGroupCodeAsync", request);
		return rpcRst;
	}

	Future<bool> createVideoAsync(SaveVideoRequest request) async {
		var rpcRst = await call("CreateVideoAsync", request);
		return rpcRst;
	}

	Future<PageResult<VideoInfoDTO>> findVideosPagesAsync(FindVideoPagesRequest request) async {
		var rpcRst = await call("FindVideosPagesAsync", request);
		var result = PageResult<VideoInfoDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> deleteVideoByCodeAsync(DeleteVideoRequest request) async {
		var rpcRst = await call("DeleteVideoByCodeAsync", request);
		return rpcRst;
	}

	Future<BuyCourseResult> buyCourseAsync(BuyCourseRequest request) async {
		var rpcRst = await call("BuyCourseAsync", request);
		var result = BuyCourseResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> paymentCallbackAsync(PaymentCallbackRequest request) async {
		var rpcRst = await call("PaymentCallbackAsync", request);
		return rpcRst;
	}

	Future<bool> signUpCourseAsync(SignUpCourseRequest request) async {
		var rpcRst = await call("SignUpCourseAsync", request);
		return rpcRst;
	}

	Future<bool> cancelSignUpCourseAsync(CancelSignUpCourseRequest request) async {
		var rpcRst = await call("CancelSignUpCourseAsync", request);
		return rpcRst;
	}

	Future<bool> publishCourseExaminationPaperAsync(PublishCourseExaminationPaperRequest request) async {
		var rpcRst = await call("PublishCourseExaminationPaperAsync", request);
		return rpcRst;
	}

	Future<List<BaseCourseExaminationDTO>> findCourseExaminationPapersAsync(FindCourseExaminationPapersRequest request) async {
		var rpcRst = await call("FindCourseExaminationPapersAsync", request);
		var result = (rpcRst as List).map((e)=>BaseCourseExaminationDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<CourseExaminationDTO> findCourseExaminationPaperByCodeAsync(FindCourseExaminationPaperByCodeRequest request) async {
		var rpcRst = await call("FindCourseExaminationPaperByCodeAsync", request);
		var result = CourseExaminationDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> submitCourseExaminationPaperAsync(SubmitCourseExaminationPaperRequest request) async {
		var rpcRst = await call("SubmitCourseExaminationPaperAsync", request);
		return rpcRst;
	}

	Future<PageResult<BaseStudentExaminationDTO>> findCourseStudentExaminationPagesAsync(FindCourseStudentExaminationPagesRequest request) async {
		var rpcRst = await call("FindCourseStudentExaminationPagesAsync", request);
		var result = PageResult<BaseStudentExaminationDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<StudentExaminationDetailDTO> findStudentExaminationByCodeAsync(FindStudentExaminationByCodeRequest request) async {
		var rpcRst = await call("FindStudentExaminationByCodeAsync", request);
		var result = StudentExaminationDetailDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> submitReviewStudentExaminationAsync(SubmitReviewStudentExaminationRequest request) async {
		var rpcRst = await call("SubmitReviewStudentExaminationAsync", request);
		return rpcRst;
	}

	Future<PageResult<BaseStudentExaminationDTO>> findMyCourseStudentExaminationResultsAsync(FindMyCourseStudentExaminationResultPagesRequest request) async {
		var rpcRst = await call("FindMyCourseStudentExaminationResultsAsync", request);
		var result = PageResult<BaseStudentExaminationDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<StudentExaminationDetailDTO> findMyCourseStudentExaminationResultAsync(FindMyCourseStudentExaminationResultRequest request) async {
		var rpcRst = await call("FindMyCourseStudentExaminationResultAsync", request);
		var result = StudentExaminationDetailDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<InitiateLiveCourseResult> initiateLiveCourseAsync(InitiateLiveCourseRequest request) async {
		var rpcRst = await call("InitiateLiveCourseAsync", request);
		var result = InitiateLiveCourseResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<JoinLiveCourseResult> joinLiveCourseAsync(JoinLiveCourseRequest request) async {
		var rpcRst = await call("JoinLiveCourseAsync", request);
		var result = JoinLiveCourseResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<LiveHeartRateResult> heartRateAsync(LiveHeartRateRequest request) async {
		var rpcRst = await call("HeartRateAsync", request);
		var result = LiveHeartRateResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<LiveCourseBaseResult> leaveLiveCourseAsync(JoinLiveCourseRequest request) async {
		var rpcRst = await call("LeaveLiveCourseAsync", request);
		var result = LiveCourseBaseResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<LiveCourseBaseResult> setMuteLiveCourseAsync(SetMuteLiveCourseRequest request) async {
		var rpcRst = await call("SetMuteLiveCourseAsync", request);
		var result = LiveCourseBaseResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<LiveCourseBaseResult> setVideoLiveCourseAsync(SetVideoLiveCourseRequest request) async {
		var rpcRst = await call("SetVideoLiveCourseAsync", request);
		var result = LiveCourseBaseResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> setControlParameterLiveCourseAsync(ControlParameterInCourseRequest request) async {
		var rpcRst = await call("SetControlParameterLiveCourseAsync", request);
		return rpcRst;
	}

	Future<LiveCourseMember> deviceJoinInLiveCourseAsync(JoinLiveCourseRequest request) async {
		var rpcRst = await call("DeviceJoinInLiveCourseAsync", request);
		var result = LiveCourseMember.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> uploadRemoteExaminationDataAsync(UploadRemoteExamRequest request) async {
		var rpcRst = await call("UploadRemoteExaminationDataAsync", request);
		return rpcRst;
	}

	Future<List<RemoteExaminationPageDTO>> getRemoteExaminationList(TokenRequest request) async {
		var rpcRst = await call("GetRemoteExaminationList", request);
		var result = (rpcRst as List).map((e)=>RemoteExaminationPageDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> addStudentInCourseUserGroupAsync(AddStudentInCourseUserGroupRequest request) async {
		var rpcRst = await call("AddStudentInCourseUserGroupAsync", request);
		return rpcRst;
	}

	Future<bool> studyCompletedAsync(StudyCompletedRequest request) async {
		var rpcRst = await call("StudyCompletedAsync", request);
		return rpcRst;
	}

}

