import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'rank.m.dart';


class RankService extends JsonRpcClientBase {
	RankService(
		String host, {
		String serviceName = "IRankService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => RankDTO.fromJson(map));
	}

	Future<RankDTO> getRankByCodeAsync(GetRankByCodeRequest request) async {
		var rpcRst = await call("GetRankByCodeAsync", request);
		var result = RankDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<RankDTO>> getAllRanksAsync(GetRanksRequest request) async {
		var rpcRst = await call("GetAllRanksAsync", request);
		var result = (rpcRst as List).map((e)=>RankDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> addRanksAsync(AddRanksRequest request) async {
		var rpcRst = await call("AddRanksAsync", request);
		return rpcRst;
	}

	Future<bool> removeRanksAsync(RemoveRanksRequest request) async {
		var rpcRst = await call("RemoveRanksAsync", request);
		return rpcRst;
	}

	Future<bool> updateRankNameAsync(UpdateRankNameRequest request) async {
		var rpcRst = await call("UpdateRankNameAsync", request);
		return rpcRst;
	}

}

